Documentation
¶
Index ¶
- func EqualFold(b, s string) bool
- func MakeNoZero(l int) []byte
- func MakeNoZeroCap(l int, c int) []byte
- func Repeat(s string, count int) string
- func ReplaceAll(s, old, new string) string
- func ReplaceString(s, old, new string, n int) string
- func ToLower(s string) string
- func ToString(arg any, timeFormat ...string) string
- func ToUpper(s string) string
- type Builder
- func (b *Builder) Cap() int
- func (b *Builder) Grow(n int)
- func (b *Builder) Len() int
- func (b *Builder) Reset()
- func (b *Builder) ResetAndKeepCap()
- func (b *Builder) String() string
- func (b *Builder) Write(p []byte) (int, error)
- func (b *Builder) WriteByte(c byte) error
- func (b *Builder) WriteRune(r rune) (int, error)
- func (b *Builder) WriteString(s string) (int, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MakeNoZero ¶
func MakeNoZeroCap ¶
func Repeat ¶
Repeat returns a new string consisting of count copies of the string s.
It panics if count is negative or if the result of (len(s) * count) overflows.
func ReplaceAll ¶
func ReplaceString ¶
Types ¶
type Builder ¶
type Builder struct {
// contains filtered or unexported fields
}
func NewBuilder ¶
NewBuilder returns the new Builder with preallocated cap
func (*Builder) Cap ¶
Cap returns the capacity of the builder's underlying byte slice. It is the total space allocated for the string being built and includes any bytes already written.
func (*Builder) ResetAndKeepCap ¶
func (b *Builder) ResetAndKeepCap()
ResetAndKeepCap sets all data to zero and keep cap
func (*Builder) Write ¶
Write appends the contents of p to b's buffer. Write always returns len(p), nil.
func (*Builder) WriteByte ¶
WriteByte appends the byte c to b's buffer. The returned error is always nil.
Click to show internal directories.
Click to hide internal directories.